.. include:: ../README.rst


User's Guide
============

.. toctree::
   :maxdepth: 2

   installation
   migratingfromtower
   authors
   history
   granola
              

Maintainer's Guide
==================

.. toctree::
   :maxdepth: 2

   contributing
   goals
   release


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

